==> open-xchange-spamhandler-parallels_6.22.1.orig.tar.bz2: open-xchange-spamhandler-parallels-6.22.1/com.openexchange.spamhandler.parallels/src/com/openexchange/spamhandler/parallels/Configuration.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.spamhandler.parallels;

import com.openexchange.config.ConfigurationService;

/**
 * {@link Configuration}
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public class Configuration {

    private final int port;
    private final int xmlPort;

    private Configuration(int port, int xmlPort) {
        super();
        this.port = port;
        this.xmlPort = xmlPort;
    }

    public static Configuration getInstance(ConfigurationService configService) {
        int port = configService.getIntProperty("com.openexchange.spamhandler.spamassassin.port", 783);
        int xmlPort = configService.getIntProperty("com.openexchange.custom.parallels.antispam.xmlrpc.port", 3100);
        return new Configuration(port, xmlPort);
    }

    public int getPort() {
        return port;
    }

    public int getXmlPort() {
        return xmlPort;
    }
}

==> open-xchange-spamhandler-parallels_7.0.2.orig.tar.bz2: open-xchange-spamhandler-parallels-7.0.2/com.openexchange.spamhandler.parallels/src/com/openexchange/spamhandler/parallels/Configuration.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.spamhandler.parallels;

import com.openexchange.config.ConfigurationService;
import com.openexchange.custom.parallels.impl.ParallelsOptions;

/**
 * {@link Configuration}
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public class Configuration {

    private final int port;
    private final int xmlPort;

    private Configuration(int port, int xmlPort) {
        super();
        this.port = port;
        this.xmlPort = xmlPort;
    }

    public static Configuration getInstance(ConfigurationService configService) {
        int port = configService.getIntProperty("com.openexchange.spamhandler.spamassassin.port", 783);
        int xmlPort = configService.getIntProperty(ParallelsOptions.PROPERTY_ANTISPAM_XMLRPC_PORT, 3100);
        return new Configuration(port, xmlPort);
    }

    public int getPort() {
        return port;
    }

    public int getXmlPort() {
        return xmlPort;
    }
}
